@@ -28,6 +28,20 @@ class ExpectAssert(object):
         self.caller_args = caller_args
         self.custom_msg = None
 
+    def serialize(self):
+        """ Serializes the ExpectAssert object for collection.
+
+        Warning, this will only grab the available information.
+        It is strongly that you only call this once all specs and
+        tests have completed.
+        """
+        converted_dict = {
+            'success': self.success,
+            'assertion': str(self),
+            'required': self.required
+        }
+        return converted_dict
+
     def _verify_condition(self, condition):
         self.success = condition if not self.used_negative else not condition
         if self.required and not self.success:
@@ -82,6 +96,14 @@ class ExpectAssert(object):
         self._compare(action_name=_('be in'), expected=expected,
                       condition=self.target in expected)
 
+    def be_a(self, expected):
+        self._compare(action_name=_('be a'), expected=expected,
+                      condition=type(self.target) is expected)
+
+    def be_an_instance_of(self, expected):
+        self._compare(action_name=_('be an instance of'), expected=expected,
+                      condition=isinstance(self.target, expected))
+
     def raise_a(self, exception):
         self.expected = exception
         self.actions.extend(['raise', exception])
