@@ -9,6 +9,9 @@ class AbstractReporterPlugin(object):
     serial reporter abstracts depending on your use case.
     """
 
+    def add_arguments(self, argparser):
+        pass  # pragma: no cover
+
     def process_arguments(self, args):
         pass  # pragma: no cover
 
@@ -20,7 +23,7 @@ class AbstractReporterPlugin(object):
         pass  # pragma: no cover
 
     @abstractmethod
-    def subscribe_to_describe(self, describe):
+    def subscribe_to_spec(self, spec):
         pass  # pragma: no cover
 
 
@@ -54,6 +57,9 @@ class ReporterPluginManager(object):
                 if issubclass(type(reporter), AbstractConsoleReporter) and
                 self.can_use_reporter(reporter, self.parallel)]
 
+    def add_to_arguments(self, argparser):
+        [reporter.add_arguments(argparser) for reporter in self.reporters]
+
     def process_arguments(self, args):
         self.parallel = args.parallel
         [reporter.process_arguments(args) for reporter in self.reporters]
@@ -68,13 +74,13 @@ class ReporterPluginManager(object):
                 can_use = True
         return can_use
 
-    def subscribe_all_to_describe(self, describe):
+    def subscribe_all_to_spec(self, spec):
         """ Will automatically not subscribe reporters that are not parallel
         or serial depending on the current mode.
         """
         for reporter in self.reporters:
             if self.can_use_reporter(reporter, self.parallel):
-                reporter.subscribe_to_describe(describe)
+                reporter.subscribe_to_spec(spec)
 
     def finish_all(self):
         [reporter.finished() for reporter in self.reporters]
