@@ -1,6 +1,7 @@
 from xml.etree.ElementTree import Element, tostring as element_to_str
 
 import six
+from specter import _
 from specter.spec import DescribeEvent
 from specter.reporting import AbstractParallelReporter, AbstractSerialReporter
 
@@ -13,6 +14,11 @@ class XUnitReporter(AbstractSerialReporter, AbstractParallelReporter):
         self.suites = []
         self.filename = ''
 
+    def add_arguments(self, argparser):
+        argparser.add_argument(
+            '--xunit-results', dest='xunit_results', metavar='',
+            help=_('Saves out xUnit compatible results to a specifed file'))
+
     def process_arguments(self, args):
         if args.xunit_results:
             self.filename = args.xunit_results
@@ -20,8 +26,8 @@ class XUnitReporter(AbstractSerialReporter, AbstractParallelReporter):
     def get_name(self):
         return 'xUnit report generator'
 
-    def subscribe_to_describe(self, describe):
-        describe.add_listener(DescribeEvent.COMPLETE, self.describe_complete)
+    def subscribe_to_spec(self, spec):
+        spec.add_listener(DescribeEvent.COMPLETE, self.describe_complete)
 
     def describe_complete(self, evt):
         describe = evt.payload
