@@ -45,9 +45,6 @@ class SpecterRunner(object):
         self.arg_parser.add_argument(
             '--no-color', dest='no_color', action='store_true',
             help=_('Disables all ASCII color codes.'))
-        self.arg_parser.add_argument(
-            '--xunit-results', dest='xunit_results', metavar='',
-            help=_('Saves out xUnit compatible results to a specifed file'))
         self.arg_parser.add_argument(
             '--parallel', dest='parallel', action='store_true',
             help=_('Activate parallel testing mode'))
@@ -94,9 +91,10 @@ class SpecterRunner(object):
 
     def run(self, args):
         select_meta = None
-        self.arguments = self.arg_parser.parse_args(args)
-
         self.reporter_manager = ReporterPluginManager()
+        self.reporter_manager.add_to_arguments(self.arg_parser)
+
+        self.arguments = self.arg_parser.parse_args(args)
 
         # Let each reporter parse cli arguments
         self.reporter_manager.process_arguments(self.arguments)
@@ -132,7 +130,7 @@ class SpecterRunner(object):
 
             suite = suite_type()
             self.suites.append(suite)
-            self.reporter_manager.subscribe_all_to_describe(suite)
+            self.reporter_manager.subscribe_all_to_spec(suite)
             suite.execute(select_metadata=select_meta,
                           parallel_manager=self.parallel_manager)
 
