@@ -1,3 +1,4 @@
+import copy
 import inspect
 import itertools
 import sys
@@ -10,7 +11,8 @@ from pyevents.manager import EventDispatcher
 from pyevents.event import Event
 from specter.util import (get_real_last_traceback, convert_camelcase,
                           find_by_metadata, extract_metadata,
-                          children_with_tests_with_metadata)
+                          children_with_tests_with_metadata,
+                          remove_empty_entries_from_dict)
 
 
 class TimedObject(object):
@@ -46,6 +48,31 @@ class CaseWrapper(TimedObject):
         self.execute_kwargs = execute_kwargs
         self.metadata = metadata
 
+    def serialize(self):
+        """ Serializes the CaseWrapper object for collection.
+
+        Warning, this will only grab the available information.
+        It is strongly that you only call this once all specs and
+        tests have completed.
+        """
+        expects = [exp.serialize() for exp in self.expects]
+        converted_dict = {
+            'id': self.id,
+            'name': self.pretty_name,
+            'raw_name': self.name,
+            'doc': self.doc,
+            'error': self.error,
+            'skipped': self.skipped,
+            'skip_reason': self.skip_reason,
+            'execute_kwargs': self.safe_execute_kwargs,
+            'metadata': self.metadata,
+            'start': self.start_time,
+            'end': self.end_time,
+            'expects': expects,
+            'success': self.success
+        }
+        return remove_empty_entries_from_dict(converted_dict)
+
     def execute(self, context=None):
         kwargs = {}
         if self.execute_kwargs:
@@ -94,6 +121,17 @@ class CaseWrapper(TimedObject):
     def complete(self):
         return self.end_time > 0.0
 
+    @property
+    def safe_execute_kwargs(self):
+        safe_kwargs = copy.deepcopy(self.execute_kwargs)
+        if not safe_kwargs:
+            return
+
+        for k, v in six.iteritems(safe_kwargs):
+            if type(v) not in [str, int, list, bool, dict]:
+                safe_kwargs[k] = str(v)
+        return safe_kwargs
+
     def __getstate__(self):
         altered = dict(self.__dict__)
         if 'case_func' in altered:
@@ -234,6 +272,27 @@ class Describe(EventDispatcher):
     def is_fixture(cls):
         return vars(cls).get('__FIXTURE__') is True
 
+    def serialize(self):
+        """ Serializes the Spec/Describe object for collection.
+
+        Warning, this will only grab the available information.
+        It is strongly that you only call this once all specs and
+        tests have completed.
+        """
+
+        cases = [case.serialize() for key, case in six.iteritems(self.cases)]
+        specs = [spec.serialize() for spec in self.describes]
+
+        converted_dict = {
+            'id': self.id,
+            'name': self.name,
+            'class_path': self.real_class_path,
+            'doc': self.doc,
+            'cases': cases,
+            'specs': specs
+        }
+        return converted_dict
+
     def __create_state_obj__(self):
         """ Generates the clean state object magic. Here be dragons! """
         stops = [Describe, Spec, DataDescribe, EventDispatcher]
@@ -334,8 +393,10 @@ class Describe(EventDispatcher):
         if type(obj) is not FunctionType:
             return False
 
-        reserved = ['execute', 'standard_execution', 'parallel_execution',
-                    'before_each', 'after_each', 'before_all', 'after_all']
+        reserved = [
+            'execute', 'standard_execution', 'parallel_execution', 'serialize',
+            'before_each', 'after_each', 'before_all', 'after_all'
+        ]
 
         func_name = obj.__name__
         return (not func_name.startswith('_') and
